==> messaging-4.2.0-sources.jar: com/liveperson/messaging/commands/InitAmsSessionCommand.java <==
package com.liveperson.messaging.commands;

import com.liveperson.infra.Command;
import com.liveperson.infra.ICallback;
import com.liveperson.infra.InternetConnectionService;
import com.liveperson.infra.log.LPMobileLog;
import com.liveperson.infra.utils.ThreadPoolExecutor;
import com.liveperson.messaging.Messaging;
import com.liveperson.messaging.SocketTaskType;
import com.liveperson.messaging.commands.tasks.BaseAmsSocketConnectionCallback;
import com.liveperson.messaging.commands.tasks.BaseAmsSocketConnectionTask;
import com.liveperson.messaging.commands.tasks.GetAgentUserTask;
import com.liveperson.messaging.commands.tasks.GetClockTask;
import com.liveperson.messaging.commands.tasks.GetConsumerUserTask;
import com.liveperson.messaging.commands.tasks.HandlePendingMessagesTask;
import com.liveperson.messaging.commands.tasks.RefreshNotUpdatedConversationsTask;
import com.liveperson.messaging.commands.tasks.SubscribeExConversationsTask;
import com.liveperson.messaging.commands.tasks.UnsubscribeExConversationTask;

import java.util.LinkedList;

/**
 * Created by ofira on 24/12/2015.
 */
public class InitAmsSessionCommand implements Command {

    private static final String TAG = InitAmsSessionCommand.class.getSimpleName();
    protected final Messaging mController;
    protected LinkedList<BaseAmsSocketConnectionTask> mTasks = new LinkedList<>();
    protected String mBrandId;
    protected ICallback mCallback;

    /**
     * Create new InitAmsSessionCommand and also populate it with the predefined task
     */
    public InitAmsSessionCommand(Messaging controller, String brandId, ICallback callback) {
        mController = controller;
        mBrandId = brandId;
        mCallback = callback;
        initTasks();
    }

    protected void initTasks() {
        mTasks.add(new GetClockTask(mController));
        mTasks.add(new GetConsumerUserTask(mController));
        mTasks.add(new UnsubscribeExConversationTask(mController));
        mTasks.add(new HandlePendingMessagesTask(mController.amsMessages, mController.amsConversations, mController.amsDialogs, mController.mConnectionController));
        mTasks.add(new RefreshNotUpdatedConversationsTask(mController));
        mTasks.add(new SubscribeExConversationsTask(mController));
        mTasks.add(new GetAgentUserTask(mController));
    }

    /**
     * Execute the connection process
     */
    @Override
    public void execute() {
        if (mTasks.size() != 0) {
            //TODO: Check if we need it here, or in the infra layer
            if (InternetConnectionService.isNetworkAvailable()) {
                ThreadPoolExecutor.execute(new Runnable() {
                    @Override
                    public void run() {

                        BaseAmsSocketConnectionTask baseConnectionTask = mTasks.removeFirst();
                        baseConnectionTask.setBrandId(mBrandId);
                        baseConnectionTask.setCallback(new BaseAmsSocketConnectionCallback() {
                            @Override
                            public void onTaskSuccess() {
                                execute();
                            }

                            @Override
                            public void onTaskError(SocketTaskType type, Throwable exception) {
                                LPMobileLog.d(TAG, type.name() + " failed");
                                mCallback.onError(exception);
                            }

                        });
                        baseConnectionTask.execute();
                    }
                });
            }
        } else {
            mCallback.onSuccess(null);
        }
    }
}

==> messaging-4.6.0-sources.jar: com/liveperson/messaging/commands/InitAmsSessionCommand.java <==
package com.liveperson.messaging.commands;

import com.liveperson.infra.Command;
import com.liveperson.infra.ICallback;
import com.liveperson.infra.InternetConnectionService;
import com.liveperson.infra.log.LPLog;
import com.liveperson.infra.utils.ThreadPoolExecutor;
import com.liveperson.messaging.Messaging;
import com.liveperson.messaging.SocketTaskType;
import com.liveperson.messaging.commands.tasks.BaseAmsSocketConnectionCallback;
import com.liveperson.messaging.commands.tasks.BaseAmsSocketConnectionTask;
import com.liveperson.messaging.commands.tasks.GetAgentUserTask;
import com.liveperson.messaging.commands.tasks.GetClockTask;
import com.liveperson.messaging.commands.tasks.GetConsumerUserTask;
import com.liveperson.messaging.commands.tasks.HandlePendingMessagesTask;
import com.liveperson.messaging.commands.tasks.RefreshNotUpdatedConversationsTask;
import com.liveperson.messaging.commands.tasks.SubscribeExConversationsTask;

import java.util.LinkedList;

/**
 * Created by ofira on 24/12/2015.
 */
public class InitAmsSessionCommand implements Command {

    private static final String TAG = "InitAmsSessionCommand";
    protected final Messaging mController;
    protected LinkedList<BaseAmsSocketConnectionTask> mTasks = new LinkedList<>();
    protected String mBrandId;
    protected ICallback<Object, Throwable> mCallback;

    /**
     * Create new InitAmsSessionCommand and also populate it with the predefined task
     */
    public InitAmsSessionCommand(Messaging controller, String brandId, ICallback<Object, Throwable> callback) {
        mController = controller;
        mBrandId = brandId;
        mCallback = callback;
        initTasks();
    }

    protected void initTasks() {
        mTasks.add(new GetClockTask(mController));
        mTasks.add(new GetConsumerUserTask(mController));
        mTasks.add(new HandlePendingMessagesTask(mController.amsMessages, mController.amsConversations, mController.amsDialogs, mController.mConnectionController));
        mTasks.add(new RefreshNotUpdatedConversationsTask(mController));
        mTasks.add(new SubscribeExConversationsTask(mController));
        mTasks.add(new GetAgentUserTask(mController));
    }

    /**
     * Execute the connection process
     */
    @Override
    public void execute() {
        if (mTasks.size() != 0) {
            //TODO: Check if we need it here, or in the infra layer
            if (InternetConnectionService.isNetworkAvailable()) {
                ThreadPoolExecutor.execute(() -> {

                    BaseAmsSocketConnectionTask baseConnectionTask = mTasks.removeFirst();
                    baseConnectionTask.setBrandId(mBrandId);
                    baseConnectionTask.setCallback(new BaseAmsSocketConnectionCallback() {
                        @Override
                        public void onTaskSuccess() {
                            execute();
                        }

                        @Override
                        public void onTaskError(SocketTaskType type, Throwable exception) {
	                        LPLog.INSTANCE.d(TAG, type.name() + " failed");
                            mCallback.onError(exception);
                        }

                    });
                    baseConnectionTask.execute();
                });
            }
        } else {
            mCallback.onSuccess(null);
        }
    }
}
